==> rober19-config-2.4.11.tgz: package/README.md <==
# rober19-config

> rober19-config


[![NPM](https://img.shields.io/badge/js-on-yellow.svg)](https://www.npmjs.com/package/rober19-config) [![NPM](https://img.shields.io/badge/npm-v2-brightgreen.svg)](https://www.npmjs.com/package/rober19-config) [![NPM](https://img.shields.io/badge/ts-on-blue.svg)](https://wmjs.com/package/rober19-config) [![NPM](https://travis-ci.com/Rober19/rober19_config.svg?branch=master)](https://travis-ci.com/Rober19/rober19_config)


## Install


$ npm install rober19-config


## Usage


Javascript

```js
const { resMsg, port, resJson } = require('rober19-config/config-js');

console.log( resMsg.confirm ) //=> Confirmado
console.log( port[0] ) //=> 3000
console.log( resJson( 1, 2) ) //=> { data: 1, status: 2 }

```


Typescript

```ts
import { resMsg, port, resJson } from 'rober19-config'

console.log( resMsg.confirm ) //=> Confirmado
console.log( port[0] ) //=> 3000
console.log( resJson( 1, 2) ) //=> { data: 1, status: 2 }

```


### resMsg

```json
{
	"found": "Encontrado",
	"file": "Archivo",
	"please_login": "Ingrese aquí",
	"publications": "Publicaciones",
	"publication": "Publicacion",
	"summary": "Resumen",
	"chat": "Chat",
	"chats": "Mensajes",
	"post": "Publicar",
	"dashboard": "Dashboard",
	"followers": "Seguidores",
	"follower": "Seguidor",
	"follow": "Seguir",
	"data_upt": "Actualizar Datos",
	"image_upt": "Actualizar Imagen",
	"profile_work_zone": "Areas de trabajo",
	"profile_set1": "Gustos y Pasiones",
	"following": "Siguiendo",
	"timeline": "Timeline",
	"profile": "Perfil",
	"login": "Iniciar sesión",
	"sign_in": "Registrarse",
	"sign_out": "Desconectar",
	"register": "Registrar",
	"updates": "Cambios",
	"save": "Guardar",
	"send": "Enviar",
	"uploads": "Subidas",
	"uploaded": "Subido",
	"upload": "Subir",
	"recent": "Reciente",
	"recents": "Recientes",
	"moreRecent": "Mas Recientes",
	"Recently": "Recientemente",
	"news_1": "Nuevas",
	"username": "Nombre de Usuario",
	"link": "Enlace",
	"home": "Inicio",
	"remember": "Recordar",
	"suggestions": "Sugerencias",
	"moreSuggestions": "Más sugerencias",
	"validField_1": "Se ve bien!",
	"invalidField_1": "Debes proporcionar este dato",
	"edit": "Editar",
	"notfound": "No Encontrado",
	"confirm": "Confirmado",
	"loaded": "Cargado",
	"error": "Ha ocurrído un error",
	"deleted": "Ha sido eliminado correctamente",
	"serverOn": "Server Running",
	"serverOff": "Server Off",
	"serverErr": "Ha ocurrido un error en el servidor",
	"conectionErr": "La conexion no se ha establecido correctamente",
	"conectionOk": "La conexion se ha establecido correctamente",
	"loginOK": "Logueado correctamente",
	"loginErr": "Ha ocurrido algo malo en el ingreso",
	"user": "Usuario",
	"users": "Usuarios",
	"userNotFound": "Usuario no encontrado",
	"userFound": "Usuario encontrado",
	"userCreateOK": "Usuario creado correctamente",
	"userFollowedOK": "Usuario seguido correctamente",
	"userFollowedExist": "Usted ya sigue a este usuario",
	"userNotFollowed": "Usted no está siguiendo a este usuario",
	"userNotFollowingFound": "Usted no está siguiendo a nadie",
	"userUnfollowedOK": "Se ha dejado de seguir al correctamente",
	"userFollowedErr": "Ha ocurrido un error al seguir al usuario",
	"userUnfollowedErr": "Ha ocurrido un error al dejar de seguir al usuario",
	"userCreateErr": "Usuario no Creado",
	"RegisterOK": "Se ha registrado correctamente",
	"RegisterErr": "Ha ocurrido un error en el registro",
	"CreateOK": "Creado correctamente",
	"CreateErr": "No pudo ser creado",
	"userExist": "Usuario ya existe en la base de datos",
	"notUsers": "No hay usuarios disponibles",
	"fieldRequired": "Este campo es requerido",
	"PasswordErr": "Contraseña incorrecta",
	"SearchErr": "Ha ocurrido un error en la busqueda",
	"requestErr": "Ha ocurrido un error en la peticion",
	"nonAuthHeader": "La petición no tiene la cabecera de autenticación",
	"nonAuth": "No cumple con los permisos para hacer esta función",
	"tokenExp": "El token ha expirado",
	"tokenInvalid": "El token no es válido",
	"extensionInvalid": "La extencion es inválida",
	"limit_fileSize": "El archivo supero el tamaño aceptado",
	"limit_unexpectedFiles": "Se ha superado el limite de archivos para subir",
	"requiredFile": "No se ha enviado el archivo requerido",
	"userFollowNotSelf": "No puedes seguirte a ti mismo",
	"publicationErr": "Ha ocurrido un error al guardar la publicacion",
	"publicationsBackErr": "Ha ocurrido un error al devolver publicaciones",
	"publicationSavedOk": "Publicacion guardad con exito",
	"MessageSavedOk": "Mensaje guardad con exito",
	"MessageSendOk": "Mensaje enviado con exito",
	"notMessage": "No hay mensajes disponibles",
	"Message": "Mensaje",
	"Messages": "Mensajes",
	"publicationNotFound": "No existen o no se han encontrado publicaciones",
	"public_fileExist": "La publicación ya contiene un archivo",
	"paginate_prev": "Anterior",
	"paginate_next": "Siguiente",
	"Add_1": "Agregar",
	"Add_2": "Añadir",
	"name_1": "Nombre",
	"name_2": "Primer Nombre",
	"name_3": "Segundo Nombre",
	"name_4": "Nombres",
	"surname_1": "Apellido",
	"surname_2": "Primer Apellido",
	"surname_3": "Segundo Apellido",
	"surname_4": "Apellidos",
	"register_text1": "Este es el formulario de registro, llena todos los campos correctamente para bien de la cuenta y accede gustosamente a la plataforma, bienvenido a requiem (cuando entres podras modificar tu avatar)",
	"nickname_1": "Character",
	"username_1": "Nombre de Usuario",
	"email_address_1": "Correo electrónico",
	"email_address_2": "Email",
	"password_1": "Contraseña",
	"cart_1": "Tu cuenta",
	"price": "Precio",
	"github": "GitHub",
	"gitLab": "GitLab",
	"Ops": "Azure DevOps"
}
```

==> rober19-config-2.4.14.tgz: package/README.md <==
# rober19-config

> rober19-config


[![NPM](https://img.shields.io/badge/js-on-yellow.svg)](https://www.npmjs.com/package/rober19-config) [![NPM](https://img.shields.io/badge/npm-v2-brightgreen.svg)](https://www.npmjs.com/package/rober19-config) [![NPM](https://img.shields.io/badge/ts-on-blue.svg)](https://wmjs.com/package/rober19-config) [![NPM](https://travis-ci.com/Rober19/rober19_config.svg?branch=master)](https://travis-ci.com/Rober19/rober19_config)


## Install


$ npm install rober19-config


## Usage


Javascript

```js
const { resMsg, port, resJson } = require('rober19-config/config-js');

//port = [3000,3100,3200,3400,3500,3600,4200,8080]

console.log( resMsg.confirm ) //=> Confirmado
console.log( port[0] ) //=> 3000
console.log( resJson( 1, 2) ) //=> { data: 1, status: 2 }

```


Typescript

```ts
import { resMsg, port, resJson } from 'rober19-config'

console.log( resMsg.confirm ) //=> Confirmado
console.log( port[0] ) //=> 3000
console.log( resJson( 1, 2) ) //=> { data: 1, status: 2 }

```


### resMsg

```json
{
	"found": "Encontrado",
	"file": "Archivo",
	"please_login": "Ingrese aquí",
	"publications": "Publicaciones",
	"publication": "Publicacion",
	"summary": "Resumen",
	"chat": "Chat",
	"chats": "Mensajes",
	"post": "Publicar",
	"dashboard": "Dashboard",
	"followers": "Seguidores",
	"follower": "Seguidor",
	"follow": "Seguir",
	"data_upt": "Actualizar Datos",
	"image_upt": "Actualizar Imagen",
	"profile_work_zone": "Areas de trabajo",
	"profile_set1": "Gustos y Pasiones",
	"following": "Siguiendo",
	"timeline": "Timeline",
	"profile": "Perfil",
	"login": "Iniciar sesión",
	"sign_in": "Registrarse",
	"sign_out": "Desconectar",
	"register": "Registrar",
	"updates": "Cambios",
	"save": "Guardar",
	"send": "Enviar",
	"uploads": "Subidas",
	"uploaded": "Subido",
	"upload": "Subir",
	"recent": "Reciente",
	"recents": "Recientes",
	"moreRecent": "Mas Recientes",
	"Recently": "Recientemente",
	"news_1": "Nuevas",
	"username": "Nombre de Usuario",
	"link": "Enlace",
	"home": "Inicio",
	"remember": "Recordar",
	"suggestions": "Sugerencias",
	"moreSuggestions": "Más sugerencias",
	"validField_1": "Se ve bien!",
	"invalidField_1": "Debes proporcionar este dato",
	"edit": "Editar",
	"notfound": "No Encontrado",
	"confirm": "Confirmado",
	"loaded": "Cargado",
	"error": "Ha ocurrído un error",
	"deleted": "Ha sido eliminado correctamente",
	"serverOn": "Server Running",
	"serverOff": "Server Off",
	"serverErr": "Ha ocurrido un error en el servidor",
	"conectionErr": "La conexion no se ha establecido correctamente",
	"conectionOk": "La conexion se ha establecido correctamente",
	"loginOK": "Logueado correctamente",
	"loginErr": "Ha ocurrido algo malo en el ingreso",
	"user": "Usuario",
	"users": "Usuarios",
	"userNotFound": "Usuario no encontrado",
	"userFound": "Usuario encontrado",
	"userCreateOK": "Usuario creado correctamente",
	"userFollowedOK": "Usuario seguido correctamente",
	"userFollowedExist": "Usted ya sigue a este usuario",
	"userNotFollowed": "Usted no está siguiendo a este usuario",
	"userNotFollowingFound": "Usted no está siguiendo a nadie",
	"userUnfollowedOK": "Se ha dejado de seguir al correctamente",
	"userFollowedErr": "Ha ocurrido un error al seguir al usuario",
	"userUnfollowedErr": "Ha ocurrido un error al dejar de seguir al usuario",
	"userCreateErr": "Usuario no Creado",
	"RegisterOK": "Se ha registrado correctamente",
	"RegisterErr": "Ha ocurrido un error en el registro",
	"CreateOK": "Creado correctamente",
	"CreateErr": "No pudo ser creado",
	"userExist": "Usuario ya existe en la base de datos",
	"notUsers": "No hay usuarios disponibles",
	"fieldRequired": "Este campo es requerido",
	"PasswordErr": "Contraseña incorrecta",
	"SearchErr": "Ha ocurrido un error en la busqueda",
	"requestErr": "Ha ocurrido un error en la peticion",
	"nonAuthHeader": "La petición no tiene la cabecera de autenticación",
	"nonAuth": "No cumple con los permisos para hacer esta función",
	"tokenExp": "El token ha expirado",
	"tokenInvalid": "El token no es válido",
	"extensionInvalid": "La extencion es inválida",
	"limit_fileSize": "El archivo supero el tamaño aceptado",
	"limit_unexpectedFiles": "Se ha superado el limite de archivos para subir",
	"requiredFile": "No se ha enviado el archivo requerido",
	"userFollowNotSelf": "No puedes seguirte a ti mismo",
	"publicationErr": "Ha ocurrido un error al guardar la publicacion",
	"publicationsBackErr": "Ha ocurrido un error al devolver publicaciones",
	"publicationSavedOk": "Publicacion guardad con exito",
	"MessageSavedOk": "Mensaje guardad con exito",
	"MessageSendOk": "Mensaje enviado con exito",
	"notMessage": "No hay mensajes disponibles",
	"Message": "Mensaje",
	"Messages": "Mensajes",
	"publicationNotFound": "No existen o no se han encontrado publicaciones",
	"public_fileExist": "La publicación ya contiene un archivo",
	"paginate_prev": "Anterior",
	"paginate_next": "Siguiente",
	"Add_1": "Agregar",
	"Add_2": "Añadir",
	"name_1": "Nombre",
	"name_2": "Primer Nombre",
	"name_3": "Segundo Nombre",
	"name_4": "Nombres",
	"surname_1": "Apellido",
	"surname_2": "Primer Apellido",
	"surname_3": "Segundo Apellido",
	"surname_4": "Apellidos",
	"register_text1": "Este es el formulario de registro, llena todos los campos correctamente para bien de la cuenta y accede gustosamente a la plataforma, bienvenido a requiem (cuando entres podras modificar tu avatar)",
	"nickname_1": "Character",
	"username_1": "Nombre de Usuario",
	"email_address_1": "Correo electrónico",
	"email_address_2": "Email",
	"password_1": "Contraseña",
	"cart_1": "Tu cuenta",
	"price": "Precio",
	"github": "GitHub",
	"gitLab": "GitLab",
	"Ops": "Azure DevOps",
	"ports": [
		3000,
		3100,
		3200,
		3400,
		3500,
		3600,
		4200,
		8080
	]
}
```
